@@ -10,15 +10,20 @@
     
     ## Assigning function for finding initial b and e parameter values    
     findbe <- switch(method,
-    "1" = findbe1(function(x) {rVec <- log(x); rVec[!x>0] <- NA; rVec}, ytrans),
+    "1" = findbe1(function(x) {rVec <- log(x); rVec[!x>0 | !is.finite(x)] <- NA; rVec}, ytrans),
     "2" = findbe2(bfct, efct, "Anke"),
     "3" = findbe3(),
     "4" = findbe2(bfct, efct, "Normolle"))
     
     function(dframe)
     {
-        x <- dframe[, 1]
-        y <- dframe[, 2]
+        ncoldf <- ncol(dframe)
+        x <- dframe[, 1]        
+#        x <- dframe[, -ncoldf]
+        y <- dframe[, ncoldf]
+    
+#        x <- dframe[, 1]
+#        y <- dframe[, 2]
 
         ## Finding initial values for c and d parameters
         cdVal <- findcd(x, y)
